# Animu
An async wrapper for [Animu API](https://animu.ml/) written in Python.

## Key Features
- An async library.
- Anime fact, waifu & more!
- Especially made for discord bots.
- Easy to use with an object oriented design.


## Installing

**Python 3.8 or higher is required**

You can install it by following command:

```cmd
pip install animu
```


# FAQ

## How do I get the Animu API token?
To get the token, [join Discord server of Animu API](https://discord.gg/yyW389c). Move to `#bot-commands` channel. And do `-claim`. 

From there, further process should start in your DM. Good luck!

## My Token is not working anymore. Why?
Make sure that you've joined the support server, or else it won't work. If it's still not working, please ask for help in their official server.

## Any examples?
Check [examples](https://github.com/EitoZX/Animu/examples/) folder for examples.

## Any ratelimit?
Yes, 5 requests/second.

## Related Links

- [Official Animu API Discord Server](https://discord.gg/yyW389c)
